[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - yakumo.mapper.Base64
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - yakumo.exception.BadRequest: 400 Bad Request
      - yakumo.exception.Forbidden: 403 Forbidden
      - yakumo.exception.NoSuchAPI
      - yakumo.exception.NotFound: 404 NotFound
      - yakumo.exception.PaymentRequired: 402 Payment Required
      - yakumo.exception.Unauthorized: 401 Unauthorized
  - yakumo.mapper.BoolStrClass
  - yakumo.nova.v2.Client
  - yakumo.glance.v1.Client
  - yakumo.cinder.v2.Client
  - yakumo.keystone.v3.Client
  - yakumo.glance.v2.Client
  - yakumo.neutron.v2.lbaas.Client
  - yakumo.cinder.v1.Client
  - yakumo.keystone.v2.Client
  - yakumo.neutron.v2.Client
  - yakumo.Client
  - yakumo.neutron.v2.metering.Client
  - yakumo.neutron.v2.lb.Client
  - yakumo.neutron.v2.vpn.Client
  - yakumo.mapper.DateTimeClass
  - yakumo.mapper.Dict
  - yakumo.mapper.FloatStrClass
  - yakumo.mapper.IntStrClass
  - yakumo.mapper.JSONClass
  - yakumo.mapper.List
  - yakumo.base.Manager: Base class for resource managers.
    - yakumo.base.GlanceV2Manager: Base class for resource managers which don't use _json_resource_key.
      - yakumo.base.GlanceV2SubManager: Base class for sub resource managers for GlanceV2Manager.
        - yakumo.glance.v2.image_member.Manager: manager class for image membes on Image V2 API
      - yakumo.glance.v2.image.Manager: manager class for images on Image V2 API
    - yakumo.neutron.v2.network.Manager: Manager class for networks in Networking V2 API
    - yakumo.neutron.v2.metering.label.Manager: Manager class for metering labels for Networking v2 API
    - yakumo.nova.v2.fixed_ip.Manager: Manager class for fixed IPs in Compute API v2
    - yakumo.keystone.v3.service.Manager: manager class for services on Identity V3 API
    - yakumo.cinder.v2.snapshot.Manager: manager class for volume snapshots on Block Storage V2 API
    - yakumo.cinder.v1.volume.Manager: manager class for roles on Block Storage V1 API
    - yakumo.nova.v2.floating_ip.Manager: Manager class for floating IPs in Compute API v2
    - yakumo.keystone.v3.region.Manager: manager class for regions on Identity V3 API
    - yakumo.keystone.v3.role.Manager: manager class for roles on Identity V3 API
    - yakumo.neutron.v2.security_group.Manager: Manager class for security groups in Networking V2 API
    - yakumo.cinder.v1.snapshot.Manager: manager class for roles on Block Storage V1 API
    - yakumo.cinder.v2.volume_transfer.Manager: manager class for volume transfer on Block Storage V2 API
    - yakumo.glance.v1.image.Manager: manager class for images on Image V1 API
    - yakumo.keystone.v3.credential.Manager: manager class for credentials on Identity V3 API
    - yakumo.neutron.v2.lbaas.pool.Manager: Manager class for LBaaS Pools in Networking V2 API
    - yakumo.cinder.v1.volume_type.Manager: manager class for roles on Block Storage V1 API
    - yakumo.cinder.v2.volume_type.Manager: manager class for volume types on Block Storage V2 API
    - yakumo.nova.v2.server_group.Manager: Manager class for server groups in Compute API v2
    - yakumo.nova.v2.certificate.Manager: Manager class for root certificates in Compute API v2
    - yakumo.neutron.v2.lb.pool.Manager: Manager class for LB Pools in Networking V2 API
    - yakumo.keystone.v2.endpoint.Manager: manager class for endpoints on Identity V2 API
    - yakumo.nova.v2.security_group.Manager: Manager class for security groups in Compute API v2
    - yakumo.keystone.v2.role.Manager: manager class for roles on Identity V2 API
    - yakumo.nova.v2.image.Manager: Manager class for images in Compute API v2
    - yakumo.neutron.v2.port.Manager: Manager class for ports in Networking V2 API
    - yakumo.nova.v2.flavor.Manager: Manager class for flavors in Compute API v2
    - yakumo.keystone.v3.user.Manager: manager class for users on Identity V3 API
    - yakumo.keystone.v3.domain.Manager: manager class for domains on Identity V3 API
    - yakumo.neutron.v2.subnet.Manager: Manager class for subnets in Networking V2 API
    - yakumo.nova.v2.floating_ip_dns.Manager: Manager class for floating IP DNS entries in Compute API v2
    - yakumo.keystone.v3.endpoint.Manager: manager class for endpoints on Identity V3 API
    - yakumo.nova.v2.aggregate.Manager: Manager class for aggregates in Compute API v2
    - yakumo.cinder.v2.quota_set.Manager: Manager class for Quota sets in Block Storage API v2
    - yakumo.cinder.v2.volume.Manager: manager class for volumes on Block Storage V2 API
    - yakumo.nova.v2.server.Manager: Manager class for servers in Compute API v2
    - yakumo.cinder.v2.volume_backup.Manager: manager class for volume backups on Block Storage V2 API
    - yakumo.keystone.v3.project.Manager: manager class for projects on Identity V3 API
    - yakumo.nova.v2.agent.Manager: Manager class for agents in Compute API v2
    - yakumo.keystone.v2.user.Manager: manager class for users on Identity V2 API
    - yakumo.nova.v2.network.Manager: Manager class for networks in Compute API v2
    - yakumo.keystone.v2.project.Manager: manager class for projects on Identity V2 API
    - yakumo.cinder.v2.consistency_group_snapshot.Manager: manager class for consistency group snapshot on Block Storage V2 API
    - yakumo.neutron.v2.vpn.ipsec_policy.Manager: Manager class for VPN IPSec policies in Networking V2 API
    - yakumo.neutron.v2.quota.Manager: Manager class for quotas in Networking V2 API
    - yakumo.neutron.v2.metering.rule.Manager: Manager class for metering label rules for Networking v2 API
    - yakumo.cinder.v2.consistency_group.Manager: manager class for consistency group on Block Storage V2 API
    - yakumo.neutron.v2.router.Manager: Manager class for routers in Networking V2 API
    - yakumo.nova.v2.key_pair.Manager: Manager class for key pairs in Compute API v2
    - yakumo.neutron.v2.vpn.ike_policy.Manager: Manager class for VPN IKE policies in Networking V2 API
    - yakumo.neutron.v2.vpn.service.Manager: Manager class for VPN services in Networking V2 API
    - yakumo.neutron.v2.subnet_pool.Manager: Manager class for subnet pools in Compute API v2
    - yakumo.cinder.v2.qos.Manager: manager class for QoS specifications on Block Storage V2 API
    - yakumo.neutron.v2.floating_ip.Manager: Manager class for floating IPs in Networking V2 API
    - yakumo.nova.v2.floating_ip_bulk.Manager: Manager class for floating IP bulks in Compute API v2
    - yakumo.neutron.v2.lbaas.load_balancer.Manager: Manager class for LBaaS load balancers in Networking V2 API
    - yakumo.nova.v2.availability_zone.Manager: Manager class for availability zones in Compute API v2
    - yakumo.keystone.v3.group.Manager: manager class for groups on Identity V3 API
    - yakumo.nova.v2.quota_set.Manager: Manager class for Quota sets in Compute API v2
    - yakumo.neutron.v2.vpn.ipsec_site_connection.Manager: Manager class for VPN IPSec site connections in Networking V2 API
    - yakumo.nova.v2.cloudpipe.Manager: Manager class for cloudpipes in Compute API v2
    - yakumo.keystone.v2.service.Manager: manager class for services on Identity V2 API
    - yakumo.cinder.v2.service.Manager: Manager class for services in Block Storage API v2
    - yakumo.nova.v2.service.Manager: Manager class for services in Compute API v2
    - yakumo.neutron.v2.lb.health_monitor.Manager: Manager class for LB Health Monitors in Networking V2 API
    - yakumo.nova.v2.security_group_default_rule.Manager: Manager class for security group default rules in Compute API v2
    - yakumo.neutron.v2.lbaas.health_monitor.Manager: Manager class for LBaaS Health Monitors in Networking V2 API
    - yakumo.nova.v2.hypervisor.Manager: Manager class for hypervisors in Compute API v2
    - yakumo.base.SubManager: Base class for sub resource managers.
      - yakumo.base.GlanceV2SubManager: Base class for sub resource managers for GlanceV2Manager.
        - yakumo.glance.v2.image_member.Manager: manager class for image membes on Image V2 API
      - yakumo.neutron.v2.lb.member.Manager: Manager class for LB backend members in Networking V2 API
      - yakumo.neutron.v2.lb.vip.Manager: Manager class for LB virtual IPs in Networking V2 API
      - yakumo.nova.v2.interface_attachment.Manager: Manager class for interface attachment in Compute API v2
      - yakumo.neutron.v2.lbaas.member.Manager: Manager class for LBaaS backend members in Networking V2 API
      - yakumo.nova.v2.volume_attachment.Manager: Manager class for volume attachment in Compute API v2
      - yakumo.neutron.v2.security_group_rule.Manager: Manager class for security group rules in Networking V2 API
      - yakumo.neutron.v2.lbaas.listener.Manager: Manager class for LBaaS listeners in Networking V2 API
      - yakumo.nova.v2.security_group_rule.Manager: Manager class for security group rules in Compute API v2
  - yakumo.mapper.NoopClass
  - yakumo.mapper.Resource
  - yakumo.base.Resource: Base class for resources.
    - yakumo.base.GlanceV2Resource: Base class for resource managers which don't use _json_resource_key.
      - yakumo.glance.v2.image_member.Resource: resource class for image members on Image V2 API
      - yakumo.glance.v2.image.Resource: resource class for images on Image V2 API
    - yakumo.neutron.v2.floating_ip.Resource: Resource class for floating IPs in Networking V2 API
    - yakumo.neutron.v2.quota.Resource: Resource class for quotas in Networking V2 API
    - yakumo.nova.v2.aggregate.Resource: Resource class for aggregates in Compute API v2
    - yakumo.keystone.v3.endpoint.Resource: resource class for endpoints on Identity V3 API
    - yakumo.nova.v2.floating_ip.Resource: Resource class for floating IPs in Compute API v2
    - yakumo.neutron.v2.lbaas.pool.Resource: Resource class for LBaaS Pools in Networking V2 API
    - yakumo.keystone.v3.role.Resource: resource class for roles on Identity V3 API
    - yakumo.nova.v2.floating_ip_dns.Resource: Resource class for floating IP DNS entries in Compute API v2
    - yakumo.neutron.v2.router.Resource: Resource class for routers in Networking V2 API
    - yakumo.cinder.v1.volume_type.Resource: resource class for volumes on Block Storage V1 API
    - yakumo.neutron.v2.lbaas.load_balancer.Resource: Resource class for LBaaS load balancers in Networking V2 API
    - yakumo.cinder.v1.volume.Resource: resource class for volumes on Block Storage V1 API
    - yakumo.neutron.v2.subnet_pool.Resource: Resource class for subnet pools in Compute API v2
    - yakumo.neutron.v2.metering.rule.Resource: Resource class for metering label rules for Networking v2 API
    - yakumo.keystone.v2.service.Resource: resource class for services on Identity V2 API
    - yakumo.neutron.v2.lbaas.member.Resource: Resource class for LBaaS backend members in Networking V2 API
    - yakumo.cinder.v2.consistency_group_snapshot.Resource: resource class for consistency group snapshot on Block Storage V2 API
    - yakumo.nova.v2.hypervisor.Resource: Resource class for hypervisors in Compute API v2
    - yakumo.neutron.v2.lbaas.listener.Resource: Resource class for LBaaS listeners in Networking V2 API
    - yakumo.keystone.v3.domain.Resource: resource class for domains on Identity V3 API
    - yakumo.nova.v2.network.Resource: Resource class for networks in Compute API v2
    - yakumo.cinder.v2.volume_transfer.Resource: resource class for volume transfer on Block Storage V2 API
    - yakumo.neutron.v2.vpn.ipsec_policy.Resource: Resource class for VPN IPSec policies in Networking V2 API
    - yakumo.cinder.v2.quota_set.Resource: Resource class for Quota sets in Block Storage API v2
    - yakumo.nova.v2.interface_attachment.Resource: Resource class for interface attachment in Compute API v2
    - yakumo.keystone.v3.credential.Resource: resource class for credentials on Identity V3 API
    - yakumo.nova.v2.availability_zone.Resource: Resource class for availability zones in Compute API v2
    - yakumo.neutron.v2.subnet.Resource: Resource class for subnets in Networking V2 API
    - yakumo.nova.v2.key_pair.Resource: Resource class for key pairs in Compute API v2
    - yakumo.keystone.v3.group.Resource: resource class for groups on Identity V3 API
    - yakumo.keystone.v3.user.Resource: resource class for users on Identity V3 API
    - yakumo.neutron.v2.network.Resource: Resource class for networks in Networking V2 API
    - yakumo.keystone.v2.project.Resource: resource class for projects on Identity V2 API
    - yakumo.keystone.v2.role.Resource: resource class for roles on Identity V2 API
    - yakumo.nova.v2.security_group_rule.Resource: Resource class for security group rules in Compute API v2
    - yakumo.neutron.v2.vpn.ike_policy.Resource: Resource class for VPN IKE policies in Networking V2 API
    - yakumo.neutron.v2.vpn.service.Resource: Resource class for VPN services in Networking V2 API
    - yakumo.nova.v2.agent.Resource: Resource class for agents in Compute API v2
    - yakumo.keystone.v3.service.Resource: resource class for services on Identity V3 API
    - yakumo.neutron.v2.lb.vip.Resource: Resource class for LB virtual IPs in Networking V2 API
    - yakumo.cinder.v2.qos.Resource: resource class for QoS specifications on Block Storage V2 API
    - yakumo.nova.v2.fixed_ip.Resource: Resource class for fixed IPs in Compute API v2
    - yakumo.glance.v1.image.Resource: resource class for images on Image V1 API
    - yakumo.neutron.v2.security_group.Resource: Resource class for security groups in Networking V2 API
    - yakumo.cinder.v1.snapshot.Resource: resource class for volumes on Block Storage V1 API
    - yakumo.keystone.v3.project.Resource: resource class for projects on Identity V3 API
    - yakumo.nova.v2.certificate.Resource: Resource class for root certificates in Compute API v2
    - yakumo.nova.v2.security_group_default_rule.Resource: Resource class for security group default rules in Compute API v2
    - yakumo.nova.v2.volume_attachment.Resource: Resource class for volume attachment in Compute API v2
    - yakumo.neutron.v2.lbaas.health_monitor.Resource: Resource class for LBaaS Health Monitors in Networking V2 API
    - yakumo.neutron.v2.lb.health_monitor.Resource: Resource class for LB Health Monitors in Networking V2 API
    - yakumo.neutron.v2.lb.member.Resource: Resource class for LB backend members in Networking V2 API
    - yakumo.nova.v2.server.Resource: Resource class for servers in Compute API v2
    - yakumo.neutron.v2.metering.label.Resource: Resource class for metering labels for Networking v2 API
    - yakumo.nova.v2.flavor.Resource: Resource class for flavors in Compute API v2
    - yakumo.cinder.v2.volume.Resource: resource class for volumes on Block Storage V2 API
    - yakumo.nova.v2.quota_set.Resource: Resource class for Quota sets in Compute API v2
    - yakumo.nova.v2.image.Resource: Resource class for images in Compute API v2
    - yakumo.keystone.v2.endpoint.Resource: resource class for endpoints on Identity V2 API
    - yakumo.neutron.v2.port.Resource: Resource class for ports in Networking V2 API
    - yakumo.neutron.v2.security_group_rule.Resource: Resource class for security group rules in Networking V2 API
    - yakumo.keystone.v3.region.Resource: resource class for regions on Identity V3 API
    - yakumo.nova.v2.service.Resource: Resource class for services in Compute API v2
    - yakumo.cinder.v2.volume_type.Resource: resource class for volume types on Block Storage V2 API
    - yakumo.nova.v2.server_group.Resource: Resource class for server groups in Compute API v2
    - yakumo.neutron.v2.lb.pool.Resource: Resource class for LB Pools in Networking V2 API
    - yakumo.cinder.v2.snapshot.Resource: resource class for volume snapshots on Block Storage V2 API
    - yakumo.cinder.v2.service.Resource: Resource class for services in Block Storage API v2
    - yakumo.cinder.v2.consistency_group.Resource: resource class for consistency group on Block Storage V2 API
    - yakumo.nova.v2.floating_ip_bulk.Resource: Resource class for floating IP bulks in Compute API v2
    - yakumo.nova.v2.security_group.Resource: Resource class for security groups in Compute API v2
    - yakumo.neutron.v2.vpn.ipsec_site_connection.Resource: Resource class for VPN IPSec site connections in Networking V2 API
    - yakumo.nova.v2.cloudpipe.Resource: Resource class for cloudpipes in Compute API v2
    - yakumo.cinder.v2.volume_backup.Resource: resource class for volume backups on Block Storage V2 API
    - yakumo.keystone.v2.user.Resource: resource class for users on Identity V2 API
  - yakumo.session.Session
  - yakumo.session.SessionProxy
  - yakumo.mapper.Simple
  - yakumo.mapper.StrIntClass